==> core-1.0.2.tgz: package/lib/fields/hiddenField.js <==
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import { generateFieldSaveKey, mountElement, unmountElement } from '../utils.js';
export class HiddenField {
    constructor(parent, form, options) {
        this.options = {
            id: '',
            type: 'hidden',
            default: null,
        };
        this.inputElement = null;
        this.containerElement = null;
        this.labelElement = null;
        this.validationElement = null;
        this._value = null;
        this.initializeOptions(options);
        this._id = this.options.id;
        this._form = form;
        this._parent = parent;
        this._type = options.type;
        this._saveKey = generateFieldSaveKey(this._form.getId(), this._id);
        this.onGui();
        this.initialize();
    }
    initializeOptions(options) {
        this.options = Object.assign({}, this.options, options);
    }
    initialize() {
        return __awaiter(this, void 0, void 0, function* () {
            this.load();
            this.update();
        });
    }
    setValue(value, save = true) {
        this._value = value;
        this.syncValue();
        this._form.setData(this._id, value);
        if (save)
            this.save();
    }
    syncValue() {
        if (this.inputElement && this.inputElement instanceof HTMLInputElement && this.inputElement.value !== this._value) {
            this.inputElement.value = String(this._value);
        }
    }
    mountToParent() {
        if (this.containerElement)
            mountElement(this.containerElement, this._parent);
    }
    createContainerElement() {
        this.containerElement = document.createElement('div');
        this.containerElement.className = 'form-field ' + this.getType();
        this.containerElement.setAttribute('id', this.getId() + '_container');
    }
    createInputElement() {
        this.inputElement = document.createElement('input');
        this.inputElement.setAttribute('id', this._id);
        this.inputElement.setAttribute('name', this.options.name || this.getId());
        this.inputElement.setAttribute('type', this.getType());
        this.inputElement.className = this.options.className;
    }
    getId() {
        return this._id;
    }
    getSaveKey() {
        return this._saveKey;
    }
    getType() {
        return this._type;
    }
    onGui() {
        this.createContainerElement();
        this.createInputElement();
        if (this.containerElement && this.inputElement)
            mountElement(this.inputElement, this.containerElement);
        this.mountToParent();
    }
    destroy() {
        if (this._parent)
            unmountElement(this._parent);
    }
    save() {
        if (this._form.savesProgress() && this._form.hasValidLicense() && this._value !== undefined) {
            localStorage.setItem(this._saveKey, JSON.stringify(this._value));
        }
    }
    load() {
        var _a;
        if (this._form.savesProgress() && this._form.hasValidLicense()) {
            const value = localStorage.getItem(this._saveKey);
            if (value !== undefined) {
                this.setValue(JSON.parse(value), false);
                return;
            }
        }
        this.setValue((_a = this.options.default) !== null && _a !== void 0 ? _a : null, false);
    }
    reset() {
        var _a;
        return __awaiter(this, void 0, void 0, function* () {
            localStorage.removeItem(this._saveKey);
            this.setValue((_a = this.options.default) !== null && _a !== void 0 ? _a : null, false);
            this.update();
        });
    }
    update() {
        return __awaiter(this, void 0, void 0, function* () {
            return;
        });
    }
}

==> core-1.0.14.tgz: package/lib/fields/hiddenField.js <==
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import { generateFieldSaveKey, mountElement, unmountElement } from '../utils.js';
export class HiddenField {
    constructor(parent, form, options) {
        this.options = {
            id: '',
            type: 'hidden',
            default: null,
        };
        this.inputElement = null;
        this.containerElement = null;
        this.labelElement = null;
        this.validationElement = null;
        this._value = null;
        this.initializeOptions(options);
        this._id = this.options.id;
        this._form = form;
        this._parent = parent;
        this._type = options.type;
        this._saveKey = generateFieldSaveKey(this._form.getId(), this._id);
        this.onGui();
        this.initialize();
    }
    initializeOptions(options) {
        this.options = Object.assign({}, this.options, options);
    }
    initialize() {
        return __awaiter(this, void 0, void 0, function* () {
            this.load();
            this.update();
        });
    }
    setValue(value, save = true) {
        this._value = value;
        this.syncValue();
        this._form.setData(this._id, value);
        if (save)
            this.save();
    }
    getValue() {
        return this._value;
    }
    syncValue() {
        if (this.inputElement && this.inputElement instanceof HTMLInputElement && this.inputElement.value !== this._value) {
            this.inputElement.value = this._value;
        }
    }
    mountToParent() {
        if (this.containerElement)
            mountElement(this.containerElement, this._parent);
    }
    createContainerElement() {
        this.containerElement = document.createElement('div');
        this.containerElement.className = 'form-field ' + this.getType();
        this.containerElement.setAttribute('id', this.getId() + '_container');
    }
    createInputElement() {
        this.inputElement = document.createElement('input');
        this.inputElement.setAttribute('id', this._id);
        this.inputElement.setAttribute('name', this.options.name || this.getId());
        this.inputElement.setAttribute('type', this.getType());
        this.inputElement.className = this.options.className;
    }
    getId() {
        return this._id;
    }
    getSaveKey() {
        return this._saveKey;
    }
    getType() {
        return this._type;
    }
    getForm() {
        return this._form;
    }
    onGui() {
        this.createContainerElement();
        this.createInputElement();
        if (this.containerElement && this.inputElement)
            mountElement(this.inputElement, this.containerElement);
        this.mountToParent();
    }
    destroy() {
        if (this._parent)
            unmountElement(this._parent);
    }
    save() {
        if (this._form.savesProgress() && this._form.hasValidLicense() && this._value !== undefined) {
            localStorage.setItem(this._saveKey, JSON.stringify(this._value));
        }
    }
    load() {
        var _a;
        if (this._form.savesProgress() && this._form.hasValidLicense()) {
            const value = localStorage.getItem(this._saveKey);
            if (value) {
                this.setValue(JSON.parse(value), false);
                return;
            }
        }
        this.setValue((_a = this.options.default) !== null && _a !== void 0 ? _a : null, false);
    }
    reset() {
        var _a;
        return __awaiter(this, void 0, void 0, function* () {
            localStorage.removeItem(this._saveKey);
            this.setValue((_a = this.options.default) !== null && _a !== void 0 ? _a : null, false);
            this.update();
        });
    }
    update() {
        return __awaiter(this, void 0, void 0, function* () {
            return;
        });
    }
}
